
.. automodule:: bci_framework.default_extensions
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bci_framework.default_extensions.Class_motor_imagery
   bci_framework.default_extensions.Class_motor_imagery_Pacman
   bci_framework.default_extensions.OpenBCI_Auxiliar_data
   bci_framework.default_extensions.OpenBCI_Raw_EEG
   bci_framework.default_extensions.OpenBCI_Raw_topoplot
   bci_framework.default_extensions.P300_Speller
   bci_framework.default_extensions.P300_online_classifier
   bci_framework.default_extensions.Resting_state_and_noise_acquisition
   bci_framework.default_extensions.Tutorial_Fourier_stream_consumer
   bci_framework.default_extensions.Tutorial_Fourier_stream_produser
   bci_framework.default_extensions.Tutorial_Marker_slicing
   bci_framework.default_extensions.Tutorial_Objects_measurement
   bci_framework.default_extensions.Tutorial_Pipelines
   bci_framework.default_extensions.Visual_working_memory
   bci_framework.default_extensions.latency_synchronization_stimuli_marker
   bci_framework.default_extensions.latency_synchronization_visualization
